# snake-python
A simple python snake game

### Known Issues
* No support for multiple players
* When snake drives over itself, it will not be redrawn

### Development
For development, please use `pip install -e .` to install the project as an editable package.